@@ -1,4 +1,4 @@
-__version__ = "0.1.1"
+__version__ = "0.1.25"
 
 from .storage import *
 from .calibration import * 
@@ -11,7 +11,7 @@ from .xphysics import *
 from .interactive_visualization import * 
 
 #from .segmentation import * 
-#from .speckles import * 
+from .speckles import * 
 
 #from .fingerprints import * 
 
